package controllers

import (
	"time"

	oclib "cloud.o-forge.io/core/oc-lib"
	dbs "cloud.o-forge.io/core/oc-lib/dbs"
	beego "github.com/beego/beego/v2/server/web"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

// Operations about workflow
type WorkflowExecutionController struct {
	beego.Controller
}

// @Title Search
// @Description search workspace
// @Param	start_date		path 	string	true		"the word search you want to get"
// @Param	end_date		path 	string	true		"the word search you want to get"
// @Success 200 {workspace} models.workspace
// @router /search/:start_date/:end_date [get]
func (o *WorkflowExecutionController) Search() {
	/*
	* This is a sample of how to use the search function
	* The search function is used to search for data in the database
	* The search function takes in a filter and a data type
	* The filter is a struct that contains the search parameters
	* The data type is an enum that specifies the type of data to search for
	* The search function returns a list of data that matches the filter
	* The data is then returned as a json object
	 */
	// store and return Id or post with UUID
	start_date, _ := time.Parse("2006-01-02", o.Ctx.Input.Param(":start_date"))
	end_date, _ := time.Parse("2006-01-02", o.Ctx.Input.Param(":end_date"))
	sd := primitive.NewDateTimeFromTime(start_date)
	ed := primitive.NewDateTimeFromTime(end_date)
	f := dbs.Filters{
		And: map[string][]dbs.Filter{
			"execution_date": {{Operator: "gte", Value: sd}, {Operator: "lte", Value: ed}},
		},
	}
	o.Data["json"] = oclib.Search(&f, "", oclib.LibDataEnum(oclib.WORKFLOW_EXECUTION))
	o.ServeJSON()
}

// @Title GetAll
// @Description find workflow by workflowid
// @Success 200 {workflow} models.workflow
// @router / [get]
func (o *WorkflowExecutionController) GetAll() {
	o.Data["json"] = oclib.LoadAll(oclib.LibDataEnum(oclib.WORKFLOW_EXECUTION))
	o.ServeJSON()
}

// @Title Get
// @Description find workflow by workflowid
// @Param	id		path 	string	true		"the workflowid you want to get"
// @Success 200 {workflow} models.workflow
// @router /:id [get]
func (o *WorkflowExecutionController) Get() {
	id := o.Ctx.Input.Param(":id")
	o.Data["json"] = oclib.LoadOne(oclib.LibDataEnum(oclib.WORKFLOW_EXECUTION), id)
	o.ServeJSON()
}
